<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="el">
<context>
    <name>ScrobblerFactory</name>
    <message>
        <location filename="../scrobblerfactory.cpp" line="31"/>
        <source>Scrobbler Plugin</source>
        <translation>Πρόσθετο Scrobbler</translation>
    </message>
    <message>
        <location filename="../scrobblerfactory.cpp" line="51"/>
        <source>About Scrobbler Plugin</source>
        <translation>Σχετικά με το πρόσθετο Scrobbler</translation>
    </message>
    <message>
        <location filename="../scrobblerfactory.cpp" line="52"/>
        <source>Qmmp AudioScrobbler Plugin</source>
        <translation>Qmmp πρόσθετο AudioScrobbler</translation>
    </message>
    <message>
        <location filename="../scrobblerfactory.cpp" line="53"/>
        <source>Written by: Ilya Kotov &lt;forkotov02@ya.ru&gt;</source>
        <translation>Γράφτηκε από τον: Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</translation>
    </message>
</context>
<context>
    <name>SettingsDialog</name>
    <message>
        <location filename="../settingsdialog.ui" line="14"/>
        <source>Scrobbler Plugin Settings</source>
        <translation>Ρυθμίσεις πρόσθετου Scrobbler</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="20"/>
        <source>Last.fm</source>
        <translation>Last.fm</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="31"/>
        <location filename="../settingsdialog.ui" line="104"/>
        <source>Session:</source>
        <translation>Συνεδρία:</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="41"/>
        <location filename="../settingsdialog.ui" line="117"/>
        <source>Check</source>
        <translation>Έλεγχος</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="63"/>
        <location filename="../settingsdialog.ui" line="95"/>
        <source>Register new session</source>
        <translation>Εγγραφή νέας συνεδρίας</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="73"/>
        <source>Libre.fm</source>
        <translation>Libre.fm</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="106"/>
        <location filename="../settingsdialog.cpp" line="132"/>
        <location filename="../settingsdialog.cpp" line="183"/>
        <source>Message</source>
        <translation>Μήνυμα</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="107"/>
        <source>1. Wait for browser startup</source>
        <translation>1. Αναμονή εκκίνησης φυλλομετρητή</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="108"/>
        <source>2. Allow Qmmp to scrobble tracks to your %1 account</source>
        <translation>2. Επιτρέψτε στο Qmmp να κάνει αποθήκευση scrobble των κομματιών στο λογαριασμό σας στο %1</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="109"/>
        <source>3. Press &quot;OK&quot;</source>
        <translation>3. Πιέστε «Εντάξει»</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="114"/>
        <location filename="../settingsdialog.cpp" line="118"/>
        <location filename="../settingsdialog.cpp" line="147"/>
        <location filename="../settingsdialog.cpp" line="151"/>
        <location filename="../settingsdialog.cpp" line="191"/>
        <location filename="../settingsdialog.cpp" line="195"/>
        <source>Error</source>
        <translation>Σφάλμα</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="114"/>
        <location filename="../settingsdialog.cpp" line="147"/>
        <location filename="../settingsdialog.cpp" line="191"/>
        <source>Network error</source>
        <translation>Σφάλμα δικτύου</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="118"/>
        <location filename="../settingsdialog.cpp" line="151"/>
        <source>Unable to register new session</source>
        <translation>Αδύνατη η εγγραφή νέας συνεδρίας</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="132"/>
        <source>New session has been received successfully</source>
        <translation>Η νέα συνεδρία ελήφθη επιτυχώς</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="183"/>
        <source>Permission granted</source>
        <translation>Η άδεια εκχωρήθηκε</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="195"/>
        <source>Permission denied</source>
        <translation>Άρνηση χορήγησης άδειας</translation>
    </message>
</context>
</TS>
